==> kprima-0.1.tar.gz: kprima-0.1/kprima/resource.h <==
/***************************************************************************
                          resource.h  -  description                              
                             -------------------                                         
    begin                : Tue May 18 16:19:15 MEST 1999
                                           
    copyright            : (C) 1999 by Torsten Uhlmann                         
    email                : TUhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef RESSOURCE_H
#define RESSOURCE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

///////////////////////////////////////////////////////////////////
// resource.h  -- contains macros used for commands


///////////////////////////////////////////////////////////////////
// COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES


///////////////////////////////////////////////////////////////////
// File-menu entries
#define ID_FILE_OPEN                10030

#define ID_FILE_SAVE_AS             10060

#define ID_FILE_PREVIEW             10080
#define ID_FILE_PRINT               10090

#define ID_FILE_QUIT                10100


///////////////////////////////////////////////////////////////////
// View-menu entries                    
#define ID_VIEW_TOOLBAR             12010
#define ID_VIEW_STATUSBAR           12020
#define ID_VIEW_OPTIONS             12030
#define ID_VIEW_LOGVIEWER           12040

#define ID_SETTINGS_PRINTER         13010
#define ID_SETTINGS_SAVE            13020


///////////////////////////////////////////////////////////////////
// Help-menu entries
#define ID_HELP                     1002

#define ID_HELP_ABOUT               14010
#define ID_HELP_ABOUT_QT            14020

///////////////////////////////////////////////////////////////////
// General application values
#define ID_STATUS_MSG               1001

#define IDS_DEFAULT                 "Ready."

#define IDS_APP_ABOUT               "KPriMa\nVersion " VERSION

#endif // RESOURCE_H

==> kprima-0.2.tar.gz: kprima-0.2/kprima/resource.h <==
/***************************************************************************
                          resource.h  -  description                              
                             -------------------                                         
    begin                : Tue May 18 16:19:15 MEST 1999
                                           
    copyright            : (C) 1999 by Torsten Uhlmann                         
    email                : TUhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef RESSOURCE_H
#define RESSOURCE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

///////////////////////////////////////////////////////////////////
// resource.h  -- contains macros used for commands


///////////////////////////////////////////////////////////////////
// COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES


///////////////////////////////////////////////////////////////////
// File-menu entries
#define ID_FILE_OPEN                10030

#define ID_FILE_SAVE_AS             10060

#define ID_FILE_PREVIEW             10080
#define ID_FILE_PRINT               10090

#define ID_FILE_QUIT                10100


///////////////////////////////////////////////////////////////////
// View-menu entries                    
#define ID_VIEW_TOOLBAR             12010
#define ID_VIEW_STATUSBAR           12020
#define ID_VIEW_OPTIONS             12030
#define ID_VIEW_LOGVIEWER           12040

#define ID_SETTINGS_PRINTER         13010
#define ID_SETTINGS_SAVE            13020


///////////////////////////////////////////////////////////////////
// Help-menu entries
#define ID_HELP                     1002

#define ID_HELP_ABOUT               14010
#define ID_HELP_ABOUT_QT            14020

///////////////////////////////////////////////////////////////////
// General application values
#define ID_STATUS_MSG               1001

#define IDS_DEFAULT                 "Ready."

#define IDS_APP_ABOUT               "KPriMa\nVersion " VERSION

#define PRODUCT_INFO								"This is KPriMa Version " VERSION

#define STD_PREVIEW_COMMAND					"kghostview %PSFILE"

#endif // RESOURCE_H
